@@ -14,9 +14,9 @@ const javascriptSettings = {
 };
 
 const typescriptSettings = {
-  files: ['*.ts'],
+  files: ['*.ts', '*.mts'],
   parserOptions: {
-    project: './tsconfig.json'
+    project: './tsconfig.ts.json'
   },
   plugins: [
     '@typescript-eslint'
